function x = constr_lsq(G,y,B,b);
% x = constr_lsq(G,y,B,b);
%
% solves the constrained least-squares problem 
%
%   minimize \| y-Gx \|_2   subject to  Bx=b
%
% it is assumed that dim b <= dim x < dim b + dim y, 
% and that G and B have full rank
%
% written by Martin Hanke (29.09.2022) 
% following the exposition in Bjoerck (1996), p. 188

[Q,R] = qr(B);
d = Q'*b;

R11inv = inv(R(:,1:length(b)));
R12 = R(:,length(b)+1:end);

if length(b) == size(R,2)
   x = R11inv*d;
else
   G1 = G(:,1:length(b));
   G2 = G(:,length(b)+1:end) - G1*R11inv*R12;
   y2 = y-G1*R11inv*d;
   x2 = G2\y2;    % least-squares solution

   x1 = R11inv*(d-R12*x2);

   x = [x1;x2];
end;


