function [t,y,tt,yy,tau] = load_jung_data(n,step)
%[t,y,tt,yy,tau] = load_jung_data(n,step);
%
% load data by Jung from the paper [Jung, Hanke, Schmid (2017)]
%
% on input: n     read 2n data samples
%           step  degree of subsampling (equals tau*1000)
%
% on output: t    time stamps of samples
%            y    autocorrelation function at time stamps
%            tt   full data set
%            yy   full autocorrelation function
%            tau  grid size of time samples (equals step/1000)
% 
% AAA-scheme works well for 2n=50 data points
% for 2n=20 points, the parameter minimum_poles = 7 should be prescribed;

load jung_data.txt

tt = jung_data(:,1);
t = tt(1:step:end);
yy = jung_data(:,2);
y = yy(1:step:end);

if length(t)<2*n,
   error('*** not enough data points provided')
end;

tau = t(2);

t = t(1:2*n);
y = y(1:2*n);

