function [t,y,tt,yy,tau] = load_shea_data(n,step)
%[t,y,tt,yy,tau] = load_shea_data(n,step);
%
% load data by Shea from the paper [Bockius et al (2021)]
% with medium noise (cf. Fig.6 loc. cit, middle panel)
%
% on input: n     read 2n data samples
%           step  degree of subsampling (equals tau*100)
%
% on output: t    time stamps of samples
%            y    autocorrelation function at time stamps
%            tt   full data set
%            yy   full autocorrelation function
%            tau  grid size of time samples (equals step/100)
% 

load shea_data.txt

tt = shea_data(:,1);
t = tt(1:step:end);
yy = shea_data(:,2);
y = yy(1:step:end);

if length(t)<2*n,
   error('*** not enough data points provided')
end;

tau = t(2);

t = t(1:2*n);
y = y(1:2*n);


